@@ -1,6 +1,9 @@
+use serde_derive::Deserialize;
 use std::convert::TryFrom;
 
+#[derive(Deserialize, Default, Clone, Copy)]
 pub enum ContentType {
+    #[default]
     Json,
     Csv,
     ArrowFile,
