@@ -343,9 +343,10 @@ pub fn query_to_df(
                 })?;
                 df = df
                     .limit(
-                        usize::try_from(limit).map_err(|_| {
+                        0,
+                        Some(usize::try_from(limit).map_err(|_| {
                             invalid_query(format!("limit value too large: {}", value))
-                        })?,
+                        })?),
                     )
                     .map_err(QueryError::invalid_limit)?;
             }
@@ -440,7 +441,7 @@ mod tests {
             .filter(col("bed").gt(lit(3i64)))?
             .select(vec![col("address"), col("bed")])?
             .sort(vec![column_sort_expr_asc("bed")])?
-            .limit(10)?;
+            .limit(0, Some(10))?;
 
         assert_eq_df(df, expected_df);
 
