@@ -22,6 +22,7 @@ pub mod google_spreadsheets;
 pub mod json;
 pub mod ndjson;
 pub mod parquet;
+pub mod xlsx;
 
 #[derive(Deserialize, Clone, Debug, Eq, PartialEq)]
 #[serde(deny_unknown_fields)]
@@ -75,7 +76,7 @@ impl From<TableSchema> for arrow::datatypes::Schema {
 }
 
 #[derive(Deserialize, Debug, Clone, Eq, PartialEq)]
-pub struct TableOptionGoogleSpreasheet {
+pub struct TableOptionGoogleSpreadsheet {
     application_secret_path: String,
     sheet_title: Option<String>,
 }
@@ -167,6 +168,11 @@ impl Default for TableOptionParquet {
     }
 }
 
+#[derive(Deserialize, Debug, Clone, Eq, PartialEq)]
+pub struct TableOptionXlsx {
+    sheet_name: Option<String>,
+}
+
 #[derive(Deserialize, Debug, Clone, Eq, PartialEq)]
 pub struct TableOptionDelta {
     #[serde(default = "TableOptionDelta::default_use_memory_table")]
@@ -206,8 +212,10 @@ pub enum TableLoadOption {
     },
     csv(TableOptionCsv),
     ndjson {},
+    jsonl {},
     parquet(TableOptionParquet),
-    google_spreadsheet(TableOptionGoogleSpreasheet),
+    google_spreadsheet(TableOptionGoogleSpreadsheet),
+    xlsx(TableOptionXlsx),
     delta(TableOptionDelta),
     arrow {},
     arrows {},
@@ -217,7 +225,7 @@ pub enum TableLoadOption {
 }
 
 impl TableLoadOption {
-    fn as_google_spreadsheet(&self) -> Result<&TableOptionGoogleSpreasheet, ColumnQError> {
+    fn as_google_spreadsheet(&self) -> Result<&TableOptionGoogleSpreadsheet, ColumnQError> {
         match self {
             Self::google_spreadsheet(opt) => Ok(opt),
             _ => Err(ColumnQError::ExpectFormatOption(
@@ -226,6 +234,13 @@ impl TableLoadOption {
         }
     }
 
+    fn as_xlsx(&self) -> Result<&TableOptionXlsx, ColumnQError> {
+        match self {
+            Self::xlsx(opt) => Ok(opt),
+            _ => Err(ColumnQError::ExpectFormatOption("xlsx".to_string())),
+        }
+    }
+
     fn as_csv(&self) -> Result<&TableOptionCsv, ColumnQError> {
         match self {
             Self::csv(opt) => Ok(opt),
@@ -251,9 +266,11 @@ impl TableLoadOption {
         match self {
             Self::json { .. } => "json",
             Self::ndjson { .. } => "ndjson",
+            Self::jsonl { .. } => "jsonl",
             Self::csv { .. } => "csv",
             Self::parquet { .. } => "parquet",
             Self::google_spreadsheet(_) | Self::delta { .. } => "",
+            Self::xlsx { .. } => "xlsx",
             Self::arrow { .. } => "arrow",
             Self::arrows { .. } => "arrows",
             Self::mysql { .. } => "mysql",
@@ -412,23 +429,30 @@ impl TableSource {
         Ok(match (&self.option, &self.io_source) {
             (Some(opt), _) => opt.extension(),
             (None, TableIoSource::Uri(uri)) => {
-                let ext = Path::new(uri)
-                    .extension()
-                    .and_then(OsStr::to_str)
-                    .ok_or_else(|| {
-                        ColumnQError::InvalidUri(format!(
-                            "cannot detect table extension from uri: {}",
-                            uri
-                        ))
-                    })?;
-
-                match ext {
-                    "csv" | "json" | "parquet" | "ndjson" | "arrow" | "arrows" => ext,
-                    _ => {
-                        return Err(ColumnQError::InvalidUri(format!(
-                            "unsupported extension in uri: {}",
-                            uri
-                        )));
+                match Path::new(uri).extension().and_then(OsStr::to_str) {
+                    Some(ext) => match ext {
+                        "csv" | "json" | "ndjson" | "jsonl" | "parquet" | "arrow" | "arrows"
+                        | "xlsx" => ext,
+                        _ => {
+                            return Err(ColumnQError::InvalidUri(format!(
+                                "unsupported extension in uri: {}",
+                                uri
+                            )));
+                        }
+                    },
+                    None => {
+                        // database sources doesn't have suffix extension, parse scheme instead
+                        match TableSource::parse_option(&self.io_source) {
+                            Some(TableLoadOption::mysql {}) => "mysql",
+                            Some(TableLoadOption::sqlite {}) => "sqlite",
+                            Some(TableLoadOption::postgres {}) => "postgres",
+                            _ => {
+                                return Err(ColumnQError::InvalidUri(format!(
+                                    "unsupported extension in uri: {}",
+                                    uri
+                                )));
+                            }
+                        }
                     }
                 }
             }
@@ -445,12 +469,15 @@ pub async fn load(t: &TableSource) -> Result<Arc<dyn TableProvider>, ColumnQErro
     if let Some(opt) = &t.option {
         Ok(match opt {
             TableLoadOption::json { .. } => Arc::new(json::to_mem_table(t).await?),
-            TableLoadOption::ndjson { .. } => Arc::new(ndjson::to_mem_table(t).await?),
+            TableLoadOption::ndjson { .. } | TableLoadOption::jsonl { .. } => {
+                Arc::new(ndjson::to_mem_table(t).await?)
+            }
             TableLoadOption::csv { .. } => Arc::new(csv::to_mem_table(t).await?),
             TableLoadOption::parquet { .. } => parquet::to_datafusion_table(t).await?,
             TableLoadOption::google_spreadsheet(_) => {
                 Arc::new(google_spreadsheets::to_mem_table(t).await?)
             }
+            TableLoadOption::xlsx { .. } => Arc::new(xlsx::to_mem_table(t).await?),
             TableLoadOption::delta { .. } => delta::to_datafusion_table(t).await?,
             TableLoadOption::arrow { .. } => Arc::new(arrow_ipc_file::to_mem_table(t).await?),
             TableLoadOption::arrows { .. } => Arc::new(arrow_ipc_stream::to_mem_table(t).await?),
@@ -468,10 +495,13 @@ pub async fn load(t: &TableSource) -> Result<Arc<dyn TableProvider>, ColumnQErro
         let t: Arc<dyn TableProvider> = match t.extension()? {
             "csv" => Arc::new(csv::to_mem_table(t).await?),
             "json" => Arc::new(json::to_mem_table(t).await?),
-            "ndjson" => Arc::new(ndjson::to_mem_table(t).await?),
+            "ndjson" | "jsonl" => Arc::new(ndjson::to_mem_table(t).await?),
             "parquet" => parquet::to_datafusion_table(t).await?,
             "arrow" => Arc::new(arrow_ipc_file::to_mem_table(t).await?),
             "arrows" => Arc::new(arrow_ipc_stream::to_mem_table(t).await?),
+            "mysql" => Arc::new(database::DatabaseLoader::MySQL.to_mem_table(t)?),
+            "sqlite" => Arc::new(database::DatabaseLoader::SQLite.to_mem_table(t)?),
+            "postgresql" => Arc::new(database::DatabaseLoader::Postgres.to_mem_table(t)?),
             ext => {
                 return Err(ColumnQError::InvalidUri(format!(
                     "failed to register `{}` as table `{}`, unsupported table format `{}`",
@@ -662,12 +692,16 @@ batch_size: 512
         );
     }
 
-    #[cfg(feature = "database")]
+    #[cfg(feature = "database-sqlite")]
     #[tokio::test]
     async fn test_load_sqlite_table() -> anyhow::Result<()> {
         let t = TableSource::new("uk_cities", "sqlite://../test_data/sqlite.db");
         let table = load(&t).await?;
-        let stats = table.scan(&None, &[], None).await?.statistics();
+        let ctx = datafusion::prelude::SessionContext::new();
+        let stats = table
+            .scan(&ctx.state(), &None, &[], None)
+            .await?
+            .statistics();
         assert_eq!(stats.num_rows, Some(37));
 
         Ok(())
