@@ -7,13 +7,15 @@ use crate::table::{TableLoadOption, TableOptionParquet, TableSource};
 use datafusion::arrow;
 use datafusion::arrow::datatypes::Schema;
 use datafusion::arrow::record_batch::RecordBatch;
-use datafusion::datafusion_data_access::object_store::local::LocalFileSystem;
+use datafusion::arrow::record_batch::RecordBatchReader;
 use datafusion::datasource::file_format::parquet::ParquetFormat;
-use datafusion::datasource::listing::{ListingOptions, ListingTable, ListingTableConfig};
+use datafusion::datasource::listing::{
+    ListingOptions, ListingTable, ListingTableConfig, ListingTableUrl,
+};
 use datafusion::datasource::TableProvider;
-use datafusion::parquet::arrow::{ArrowReader, ParquetFileArrowReader};
-use datafusion::parquet::file::reader::SerializedFileReader;
-use datafusion::parquet::file::serialized_reader::SliceableCursor;
+use datafusion::parquet::arrow::arrow_reader::ArrowReaderOptions;
+use datafusion::parquet::arrow::arrow_reader::ParquetRecordBatchReaderBuilder;
+use datafusion::prelude::SessionContext;
 
 pub async fn to_datafusion_table(t: &TableSource) -> Result<Arc<dyn TableProvider>, ColumnQError> {
     let opt = t
@@ -25,25 +27,20 @@ pub async fn to_datafusion_table(t: &TableSource) -> Result<Arc<dyn TableProvide
     if *use_memory_table {
         to_mem_table(t).await
     } else {
-        let table_uri = t.parsed_uri()?;
-        let table_path = table_uri.path().to_string();
-        // TODO: pick datafusion object store based on uri
-        let df_object_store = Arc::new(LocalFileSystem {});
-        let list_opt = ListingOptions::new(Arc::new(ParquetFormat::default()));
-        let file_schema = match &t.schema {
+        let table_url = ListingTableUrl::parse(t.get_uri_str())?;
+        let options = ListingOptions::new(Arc::new(ParquetFormat::default()));
+        let schemaref = match &t.schema {
             Some(s) => Arc::new(s.into()),
             None => {
-                list_opt
-                    .infer_schema(df_object_store.clone(), &table_path)
-                    .await?
+                let ctx = SessionContext::new();
+                options.infer_schema(&ctx.state(), &table_url).await?
             }
         };
 
-        Ok(Arc::new(ListingTable::try_new(
-            ListingTableConfig::new(df_object_store, table_path)
-                .with_schema(file_schema)
-                .with_listing_options(list_opt),
-        )?))
+        let table_config = ListingTableConfig::new(table_url)
+            .with_listing_options(options)
+            .with_schema(schemaref);
+        Ok(Arc::new(ListingTable::try_new(table_config)?))
     }
 }
 
@@ -61,21 +58,19 @@ pub async fn to_mem_table(t: &TableSource) -> Result<Arc<dyn TableProvider>, Col
                 ColumnQError::LoadParquet("failed to copy parquet data into memory".to_string())
             })?;
 
-            let file_reader = SerializedFileReader::new(SliceableCursor::new(buffer))
-                .map_err(ColumnQError::parquet_file_reader)?;
-            let mut arrow_reader = ParquetFileArrowReader::new(Arc::new(file_reader));
-
-            let record_batch_reader = arrow_reader
-                .get_record_reader(batch_size)
-                .map_err(ColumnQError::parquet_record_reader)?;
-
-            let batch_schema = arrow_reader.get_schema().map_err(|_| {
-                ColumnQError::LoadParquet("failed to load schema from partition".to_string())
-            })?;
+            let record_batch_reader = ParquetRecordBatchReaderBuilder::try_new_with_options(
+                bytes::Bytes::from(buffer),
+                ArrowReaderOptions::new(),
+            )?
+            .with_batch_size(batch_size)
+            .build()?;
 
+            let batch_schema = &*record_batch_reader.schema();
             schema = Some(match &schema {
-                Some(s) if s != &batch_schema => Schema::try_merge(vec![s.clone(), batch_schema])?,
-                _ => batch_schema,
+                Some(s) if s != batch_schema => {
+                    Schema::try_merge(vec![s.clone(), batch_schema.clone()])?
+                }
+                _ => batch_schema.clone(),
             });
 
             Ok(record_batch_reader
@@ -104,12 +99,14 @@ pub async fn to_mem_table(t: &TableSource) -> Result<Arc<dyn TableProvider>, Col
 mod tests {
     use super::*;
     use std::fs;
+    use tempfile::Builder;
 
     use crate::table::TableLoadOption;
     use crate::test_util::*;
+    use datafusion::prelude::SessionContext;
 
     #[tokio::test]
-    async fn load_flattened_parquet() -> Result<(), ColumnQError> {
+    async fn load_flattened_parquet() {
         let t = to_datafusion_table(
             &TableSource::new(
                 "blogs".to_string(),
@@ -119,9 +116,15 @@ mod tests {
                 use_memory_table: false,
             })),
         )
-        .await?;
+        .await
+        .unwrap();
 
-        let stats = t.scan(&None, &[], None).await?.statistics();
+        let ctx = SessionContext::new();
+        let stats = t
+            .scan(&ctx.state(), &None, &[], None)
+            .await
+            .unwrap()
+            .statistics();
         assert_eq!(stats.num_rows, Some(500));
         let stats = stats.column_statistics.unwrap();
         assert_eq!(stats[0].null_count, Some(245));
@@ -129,7 +132,7 @@ mod tests {
         assert_eq!(stats[2].null_count, Some(237));
 
         match t.as_any().downcast_ref::<ListingTable>() {
-            Some(_) => Ok(()),
+            Some(_) => {}
             None => panic!("must be of type datafusion::datasource::listing::ListingTable"),
         }
     }
@@ -142,16 +145,8 @@ mod tests {
         ))
         .await?;
 
-        let schema = t.schema();
-        assert_eq!(
-            schema
-                .metadata()
-                .get("writer.model.name")
-                .map(|s| s.as_str()),
-            Some("protobuf")
-        );
-
-        let stats = t.scan(&None, &[], None).await?.statistics();
+        let ctx = SessionContext::new();
+        let stats = t.scan(&ctx.state(), &None, &[], None).await?.statistics();
         assert_eq!(stats.num_rows, Some(500));
 
         Ok(())
@@ -159,7 +154,9 @@ mod tests {
 
     #[tokio::test]
     async fn load_partitions() -> anyhow::Result<()> {
-        let tmp_dir = tempdir::TempDir::new("columnq.test.parquet_partitions")?;
+        let tmp_dir = Builder::new()
+            .prefix("columnq.test.parquet_partitions")
+            .tempdir()?;
         let tmp_dir_path = tmp_dir.path();
 
         let source_path = test_data_path("blogs.parquet");
@@ -173,15 +170,8 @@ mod tests {
         )
         .await?;
 
-        assert_eq!(
-            t.schema()
-                .metadata()
-                .get("writer.model.name")
-                .map(|s| s.as_str()),
-            Some("protobuf")
-        );
-
-        let stats = t.scan(&None, &[], None).await?.statistics();
+        let ctx = SessionContext::new();
+        let stats = t.scan(&ctx.state(), &None, &[], None).await?.statistics();
         assert_eq!(stats.num_rows, Some(1500));
 
         Ok(())
