@@ -1,11 +1,13 @@
 use serde_derive::Deserialize;
 
-use anyhow::{Context, Result};
+use anyhow::{bail, Context, Result};
 
+use columnq::encoding;
 use columnq::table::parse_table_uri_arg;
 use columnq::table::KeyValueSource;
 use columnq::table::TableSource;
 use std::fs;
+use std::time::Duration;
 
 #[derive(Deserialize, Default, Clone)]
 pub struct AddrConfig {
@@ -17,10 +19,13 @@ pub struct AddrConfig {
 pub struct Config {
     pub addr: AddrConfig,
     pub tables: Vec<TableSource>,
+    pub reload_interval: Option<Duration>,
     #[serde(default)]
     pub disable_read_only: bool,
     #[serde(default)]
     pub kvstores: Vec<KeyValueSource>,
+    #[serde(default)]
+    pub response_format: encoding::ContentType,
 }
 
 fn table_arg() -> clap::Arg<'static> {
@@ -64,6 +69,25 @@ fn read_only_arg() -> clap::Arg<'static> {
         .short('d')
 }
 
+fn reload_interval_arg() -> clap::Arg<'static> {
+    clap::Arg::new("reload-interval")
+        .help("maximum age in seconds before triggering rescan and reload of the tables")
+        .required(false)
+        .takes_value(true)
+        .long("reload-interval")
+        .short('r')
+}
+
+fn response_format_arg() -> clap::Arg<'static> {
+    clap::Arg::new("response-format")
+        .help("change response serialization: Json (default), Csv, ArrowFile, ArrowStream, Parquet")
+        .required(false)
+        .takes_value(true)
+        .value_name("ResponseFormat")
+        .long("response-format")
+        .short('f')
+}
+
 fn config_arg() -> clap::Arg<'static> {
     clap::Arg::new("config")
         .help("config file path")
@@ -86,6 +110,8 @@ pub fn get_configuration() -> Result<Config, anyhow::Error> {
             address_postgres_arg(),
             config_arg(),
             read_only_arg(),
+            reload_interval_arg(),
+            response_format_arg(),
             table_arg(),
         ])
         .get_matches();
@@ -118,5 +144,18 @@ pub fn get_configuration() -> Result<Config, anyhow::Error> {
         config.disable_read_only = true;
     }
 
+    if let Some(reload_interval) = matches.value_of("reload-interval") {
+        if !config.disable_read_only {
+            bail!("Table reload not supported in read-only mode. Try specify the --disable-read-only option.");
+        }
+        config.reload_interval = Some(Duration::from_secs(
+            reload_interval.to_string().parse().unwrap(),
+        ));
+    }
+
+    if let Some(response_format) = matches.value_of("response-format") {
+        config.response_format = serde_yaml::from_str(response_format)?;
+    }
+
     Ok(config)
 }
